pyxmpp.interface

Package pyxmpp :: Module interface |
[hide private]

# Source Code for Module pyxmpp.interface

     1  #
     2  # (C) Copyright 2006 Jacek Konieczny <jajcus@jajcus.net>
     3  #
     4  # This program is free software; you can redistribute it and/or modify
     5  # it under the terms of the GNU Lesser General Public License Version
     6  # 2.1 as published by the Free Software Foundation.
     7  #
     8  # This program is distributed in the hope that it will be useful,
     9  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    10  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    11  # GNU Lesser General Public License for more details.
    12  #
    13  # You should have received a copy of the GNU Lesser General Public
    14  # License along with this program; if not, write to the Free Software
    15  # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
    16  #
    17
    18  """Interface API.
    19
    20  If zope.interface is available this module will be its equivalent, otherwise
    21  minimum interface API (partially compatible with zope.interface) will be
    22  defined here.
    23
    24  When full ZopeInterfaces API is needed impoer zope.interface instead of this module."""
    25
    26  __revision__="$Id: utils.py 647 2006-08-26 18:27:39Z jajcus $"
    27
    28  try:
    29      from zope.interface import Interface, Attribute, providedBy, implementedBy, implements
    30  except ImportError:
    31      from pyxmpp.interface_micro_impl import Interface, Attribute, providedBy, implementedBy, implements
    32
    33
    34  __all__ = ("Interface", "Attribute", "providedBy", "implementedBy", "implements")
    35
    36  # vi: sts=4 et sw=4
    37